==> RSNPper_1.10.0.tar.gz: RSNPper/R/doSnpinfo.R <==
doSnpinfo = function(xmlTextVec) {
#
# (c) 2006 VJ Carey
# Function parses result of a call to snpper.chip.org
# the call is a snpinfo XML-RPC call
# the input here is a text vector result of
# useSNPper(cmd="snpinfo", parm="&[rsnumnoprefix]")
#
 tr = xmlTreeParse(paste(xmlTextVec, collapse=""), asText=TRUE)
 rtr = xmlRoot(tr)
 tinf = xmlAttrs(rtr)
 tn = names(tinf)
 tinf = t(matrix(tinf))
 colnames(tinf) = tn
 targ = xmlChildren(rtr)$SNPINFO
 elems = names(targ)
 uel = unique(elems)
 isSca = c("DBSNPID", "TSCID", "CHROMOSOME", "POSITION", "ALLELES",
   "VALIDATED")
 basic = sapply(targ[match(isSca,elems)], xmlValue)
 list(basic, rtr)
 GL = xmlChildren(targ)[names(xmlChildren(targ)) == "GENELINK"] 
 GLframe = t(sapply(GL, function(x)xmlAttrs(xmlChildren(x)[[1]])))

 ZZ = lapply(GL, function(x) xmlChildren(x[[1]]))
ZZZ = lapply(ZZ, function(x)sapply(x, function(z) xmlValue(z))) 

 SUBM = xmlChildren(targ)[names(xmlChildren(targ)) == "SUBMITTERS"]
 FREQ = xmlChildren(targ)[names(xmlChildren(targ)) == "SNPFREQDATA"]
 FRQframe = data.frame(t(sapply(xmlChildren(FREQ[[1]]), xmlAttrs)),row.names=NULL)
 al = lapply(xmlChildren(FREQ[[1]]), xmlChildren)
 majorf = sapply(al,function(x)xmlValue(x[[1]]))
 minorf = sapply(al,function(x)xmlValue(x[[2]]))
 Z=lapply(xmlChildren(FREQ[[1]]), xmlChildren)
 allfr =t(sapply(Z, function(x)unlist(lapply(x, function(z)xmlAttrs(z)))))
 doRole <- function(x) { nx = names(x); v = rep(NA,length(nx)) ;
  names(v) = nx; val = unlist(x); v[names(val)] = val; v }
 cont = t(sapply(ZZZ,doRole))
 GLframe = data.frame(cbind(GLframe,cont),row.names=NULL)
 x = list(basic=unlist(basic), popDetails=data.frame(FRQframe,allfr,majorf,minorf,row.names=NULL),
   submitters=SUBM, geneDetails=GLframe)
 DF = t(matrix((unlist(basic))))
 colnames(DF) = names(unlist(basic))
 new("SNPperMeta", popDetails= x$popDetails, geneDetails=x$geneDetails,
    submitters=SUBM, toolInfo=tinf, DF)
}

==> RSNPper_1.16.0.tar.gz: RSNPper/R/doSnpinfo.R <==
doSnpinfo = function(xmlTextVec) {
#
# (c) 2006 VJ Carey
# Function parses result of a call to snpper.chip.org
# the call is a snpinfo XML-RPC call
# the input here is a text vector result of
# useSNPper(cmd="snpinfo", parm="&[rsnumnoprefix]")
#
 tr = xmlTreeParse(paste(xmlTextVec, collapse=""), asText=TRUE)
 rtr = xmlRoot(tr)
 tinf = xmlAttrs(rtr)
 tn = names(tinf)
 tinf = t(matrix(tinf))
 colnames(tinf) = tn
 targ = xmlChildren(rtr)$SNPINFO
 elems = names(targ)
 uel = unique(elems)
 isSca = c("DBSNPID", "TSCID", "CHROMOSOME", "POSITION", "ALLELES",
   "VALIDATED")
 basic = sapply(targ[na.omit(match(isSca,elems))], xmlValue)
 list(basic, rtr)
 GL = xmlChildren(targ)[names(xmlChildren(targ)) == "GENELINK"] 
 GLframe = t(sapply(GL, function(x)xmlAttrs(xmlChildren(x)[[1]])))

 ZZ = lapply(GL, function(x) xmlChildren(x[[1]]))
ZZZ = lapply(ZZ, function(x)sapply(x, function(z) xmlValue(z))) 

 SUBM = xmlChildren(targ)[names(xmlChildren(targ)) == "SUBMITTERS"]
 FREQ = xmlChildren(targ)[names(xmlChildren(targ)) == "SNPFREQDATA"]
 tmp = t(sapply(xmlChildren(FREQ[[1]]), xmlAttrs))
 rownames(tmp) = NULL
 FRQframe = data.frame(tmp)
 al = lapply(xmlChildren(FREQ[[1]]), xmlChildren)
 majorf = sapply(al,function(x)xmlValue(x[[1]]))
 minorf = sapply(al,function(x)xmlValue(x[[2]]))
 Z=lapply(xmlChildren(FREQ[[1]]), xmlChildren)
 allfr =t(sapply(Z, function(x)unlist(lapply(x, function(z)xmlAttrs(z)))))
 doRole <- function(x) { nx = names(x); v = rep(NA,length(nx)) ;
  names(v) = nx; val = unlist(x); v[names(val)] = val; v }
 cont = t(sapply(ZZZ,doRole))
 GLframe = data.frame(cbind(GLframe,cont),row.names=NULL)
 rownames(allfr) = NULL
 pdet = data.frame(FRQframe,allfr,majorf,minorf)
 x = list(basic=unlist(basic), popDetails=pdet,
   submitters=SUBM, geneDetails=GLframe)
 DF = t(matrix((unlist(basic))))
 colnames(DF) = names(unlist(basic))
 new("SNPperMeta", popDetails= x$popDetails, geneDetails=x$geneDetails,
    submitters=SUBM, toolInfo=tinf, DF)
}
